@@ -70,6 +70,16 @@ type doPurgeOptions struct {
 	workingTree     bool
 }
 
+type commandConfig struct {
+	Command string   `json:"command" mapstructure:"command" yaml:"command"`
+	Args    []string `json:"args" mapstructure:"args" yaml:"args"`
+}
+
+type hookConfig struct {
+	Pre  commandConfig `json:"pre" mapstructure:"pre" yaml:"pre"`
+	Post commandConfig `json:"post" mapstructure:"post" yaml:"post"`
+}
+
 type templateConfig struct {
 	Options []string `json:"options" mapstructure:"options" yaml:"options"`
 }
@@ -87,6 +97,7 @@ type ConfigFile struct {
 	Format             writeDataFormat                 `json:"format" mapstructure:"format" yaml:"format"`
 	DestDirAbsPath     chezmoi.AbsPath                 `json:"destDir" mapstructure:"destDir" yaml:"destDir"`
 	GitHub             gitHubConfig                    `json:"gitHub" mapstructure:"gitHub" yaml:"gitHub"`
+	Hooks              map[string]hookConfig           `json:"hooks" mapstructure:"hooks" yaml:"hooks"`
 	Interpreters       map[string]*chezmoi.Interpreter `json:"interpreters" mapstructure:"interpreters" yaml:"interpreters"` //nolint:lll
 	Mode               chezmoi.Mode                    `json:"mode" mapstructure:"mode" yaml:"mode"`
 	Pager              string                          `json:"pager" mapstructure:"pager" yaml:"pager"`
@@ -116,6 +127,7 @@ type ConfigFile struct {
 	Onepassword       onepasswordConfig       `json:"onepassword" mapstructure:"onepassword" yaml:"onepassword"`
 	Pass              passConfig              `json:"pass" mapstructure:"pass" yaml:"pass"`
 	Passhole          passholeConfig          `json:"passhole" mapstructure:"passhole" yaml:"passhole"`
+	RBW               rbwConfig               `json:"rbw" mapstructure:"rbw" yaml:"rbw"`
 	Secret            secretConfig            `json:"secret" mapstructure:"secret" yaml:"secret"`
 	Vault             vaultConfig             `json:"vault" mapstructure:"vault" yaml:"vault"`
 
@@ -223,6 +235,7 @@ type templateData struct {
 	Arch           string          `json:"arch"`
 	Args           []string        `json:"args"`
 	CacheDir       chezmoi.AbsPath `json:"cacheDir"`
+	Command        string          `json:"command"`
 	ConfigFile     chezmoi.AbsPath `json:"configFile"`
 	Executable     chezmoi.AbsPath `json:"executable"`
 	FQDNHostname   string          `json:"fqdnHostname"`
@@ -369,6 +382,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"encrypt":                  c.encryptTemplateFunc,
 		"eqFold":                   c.eqFoldTemplateFunc,
 		"fromIni":                  c.fromIniTemplateFunc,
+		"fromJsonc":                c.fromJsoncTemplateFunc,
 		"fromToml":                 c.fromTomlTemplateFunc,
 		"fromYaml":                 c.fromYamlTemplateFunc,
 		"gitHubKeys":               c.gitHubKeysTemplateFunc,
@@ -407,6 +421,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"passhole":                 c.passholeTemplateFunc,
 		"pruneEmptyDicts":          c.pruneEmptyDictsTemplateFunc,
 		"quoteList":                c.quoteListTemplateFunc,
+		"rbw":                      c.rbwTemplateFunc,
+		"rbwFields":                c.rbwFieldsTemplateFunc,
 		"replaceAllRegex":          c.replaceAllRegexTemplateFunc,
 		"secret":                   c.secretTemplateFunc,
 		"secretJSON":               c.secretJSONTemplateFunc,
@@ -467,6 +483,7 @@ func (c *Config) addTemplateFunc(key string, value any) {
 }
 
 type applyArgsOptions struct {
+	cmd          *cobra.Command
 	filter       *chezmoi.EntryTypeFilter
 	init         bool
 	recursive    bool
@@ -483,7 +500,7 @@ func (c *Config) applyArgs(
 	options applyArgsOptions,
 ) error {
 	if options.init {
-		if err := c.createAndReloadConfigFile(); err != nil {
+		if err := c.createAndReloadConfigFile(options.cmd); err != nil {
 			return err
 		}
 	}
@@ -531,7 +548,7 @@ func (c *Config) applyArgs(
 		}
 	}
 
-	sourceState, err := c.getSourceState(ctx)
+	sourceState, err := c.getSourceState(ctx, options.cmd)
 	if err != nil {
 		return err
 	}
@@ -642,7 +659,7 @@ func (c *Config) colorAutoFunc() bool {
 
 // createAndReloadConfigFile creates a config file if it there is a config file
 // template and reloads it.
-func (c *Config) createAndReloadConfigFile() error {
+func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 	// Find config template, execute it, and create config file.
 	configTemplate, err := c.findConfigTemplate()
 	if err != nil {
@@ -656,7 +673,7 @@ func (c *Config) createAndReloadConfigFile() error {
 		return nil
 	}
 
-	configFileContents, err := c.createConfigFile(configTemplate.targetRelPath, configTemplate.contents)
+	configFileContents, err := c.createConfigFile(configTemplate.targetRelPath, configTemplate.contents, cmd)
 	if err != nil {
 		return err
 	}
@@ -702,7 +719,7 @@ func (c *Config) createAndReloadConfigFile() error {
 
 // createConfigFile creates a config file using a template and returns its
 // contents.
-func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte, error) {
+func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte, cmd *cobra.Command) ([]byte, error) {
 	funcMap := make(template.FuncMap)
 	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
 	initTemplateFuncs := map[string]any{
@@ -725,7 +742,7 @@ func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte
 		return nil, err
 	}
 
-	templateData := c.getTemplateDataMap()
+	templateData := c.getTemplateDataMap(cmd)
 	if c.init.data {
 		chezmoi.RecursiveMerge(templateData, c.Data)
 	}
@@ -1242,31 +1259,32 @@ func (c *Config) getSourceDirAbsPath(options *getSourceDirAbsPathOptions) (chezm
 	return c.sourceDirAbsPath, c.sourceDirAbsPathErr
 }
 
-func (c *Config) getSourceState(ctx context.Context) (*chezmoi.SourceState, error) {
+func (c *Config) getSourceState(ctx context.Context, cmd *cobra.Command) (*chezmoi.SourceState, error) {
 	if c.sourceState != nil || c.sourceStateErr != nil {
 		return c.sourceState, c.sourceStateErr
 	}
-	c.sourceState, c.sourceStateErr = c.newSourceState(ctx)
+	c.sourceState, c.sourceStateErr = c.newSourceState(ctx, cmd)
 	return c.sourceState, c.sourceStateErr
 }
 
 // getTemplateData returns the default template data.
-func (c *Config) getTemplateData() *templateData {
+func (c *Config) getTemplateData(cmd *cobra.Command) *templateData {
 	if c.templateData == nil {
-		c.templateData = c.newTemplateData()
+		c.templateData = c.newTemplateData(cmd)
 	}
 	return c.templateData
 }
 
-// getTemplateDataMao returns the template data as a map.
-func (c *Config) getTemplateDataMap() map[string]any {
-	templateData := c.getTemplateData()
+// getTemplateDataMap returns the template data as a map.
+func (c *Config) getTemplateDataMap(cmd *cobra.Command) map[string]any {
+	templateData := c.getTemplateData(cmd)
 
 	return map[string]any{
 		"chezmoi": map[string]any{
 			"arch":           templateData.Arch,
 			"args":           templateData.Args,
 			"cacheDir":       templateData.CacheDir.String(),
+			"command":        templateData.Command,
 			"configFile":     templateData.ConfigFile.String(),
 			"executable":     templateData.Executable.String(),
 			"fqdnHostname":   templateData.FQDNHostname,
@@ -1341,7 +1359,7 @@ func (c *Config) makeRunEWithSourceState(
 	runE func(*cobra.Command, []string, *chezmoi.SourceState) error,
 ) func(*cobra.Command, []string) error {
 	return func(cmd *cobra.Command, args []string) error {
-		sourceState, err := c.getSourceState(cmd.Context())
+		sourceState, err := c.getSourceState(cmd.Context(), cmd)
 		if err != nil {
 			return err
 		}
@@ -1494,7 +1512,7 @@ func (c *Config) newDiffSystem(s chezmoi.System, w io.Writer, dirAbsPath chezmoi
 
 // newSourceState returns a new SourceState with options.
 func (c *Config) newSourceState(
-	ctx context.Context, options ...chezmoi.SourceStateOption,
+	ctx context.Context, cmd *cobra.Command, options ...chezmoi.SourceStateOption,
 ) (*chezmoi.SourceState, error) {
 	if err := c.checkVersion(); err != nil {
 		return nil, err
@@ -1515,7 +1533,9 @@ func (c *Config) newSourceState(
 	sourceState := chezmoi.NewSourceState(append([]chezmoi.SourceStateOption{
 		chezmoi.WithBaseSystem(c.baseSystem),
 		chezmoi.WithCacheDir(c.CacheDirAbsPath),
-		chezmoi.WithDefaultTemplateDataFunc(c.getTemplateDataMap),
+		chezmoi.WithDefaultTemplateDataFunc(func() map[string]any {
+			return c.getTemplateDataMap(cmd)
+		}),
 		chezmoi.WithDestDir(c.DestDirAbsPath),
 		chezmoi.WithEncryption(c.encryption),
 		chezmoi.WithHTTPClient(httpClient),
@@ -1599,6 +1619,12 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
+	if command := c.Hooks[cmd.Name()].Post; command.Command != "" {
+		if err := c.run(c.homeDirAbsPath, command.Command, command.Args); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -1880,12 +1906,13 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	}
 
 	scriptEnv := os.Environ()
-	templateData := c.getTemplateData()
+	templateData := c.getTemplateData(cmd)
 	scriptEnv = append(scriptEnv, "CHEZMOI=1")
 	for key, value := range map[string]string{
 		"ARCH":          templateData.Arch,
 		"ARGS":          strings.Join(templateData.Args, " "),
 		"CACHE_DIR":     templateData.CacheDir.String(),
+		"COMMAND":       templateData.Command,
 		"CONFIG_FILE":   templateData.ConfigFile.String(),
 		"EXECUTABLE":    templateData.Executable.String(),
 		"FQDN_HOSTNAME": templateData.FQDNHostname,
@@ -1919,6 +1946,12 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	c.runEnv = scriptEnv
 	realSystem.SetScriptEnv(scriptEnv)
 
+	if command := c.Hooks[cmd.Name()].Pre; command.Command != "" {
+		if err := c.run(c.homeDirAbsPath, command.Command, command.Args); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -1957,7 +1990,7 @@ func (c *Config) progressAutoFunc() bool {
 	return false
 }
 
-func (c *Config) newTemplateData() *templateData {
+func (c *Config) newTemplateData(cmd *cobra.Command) *templateData {
 	// Determine the user's username and group, if possible.
 	//
 	// user.Current and user.LookupGroupId in Go's standard library are
@@ -2050,6 +2083,7 @@ func (c *Config) newTemplateData() *templateData {
 		Arch:         runtime.GOARCH,
 		Args:         os.Args,
 		CacheDir:     c.CacheDirAbsPath,
+		Command:      cmd.Name(),
 		ConfigFile:   c.configFileAbsPath,
 		Executable:   chezmoi.NewAbsPath(executable),
 		FQDNHostname: fqdnHostname,
@@ -2286,7 +2320,7 @@ func (c *Config) targetValidArgs(
 		return nil, cobra.ShellCompDirectiveError
 	}
 
-	sourceState, err := c.getSourceState(cmd.Context())
+	sourceState, err := c.getSourceState(cmd.Context(), cmd)
 	if err != nil {
 		cobra.CompErrorln(err.Error())
 		return nil, cobra.ShellCompDirectiveError
@@ -2440,6 +2474,9 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 			Command: "ph",
 			Prompt:  true,
 		},
+		RBW: rbwConfig{
+			Command: "rbw",
+		},
 		Vault: vaultConfig{
 			Command: "vault",
 		},
