@@ -302,6 +302,14 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionArgs: []string{"--version"},
 			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
 		},
+		&binaryCheck{
+			name:        "dashlane-command",
+			binaryname:  c.Dashlane.Command,
+			ifNotSet:    checkResultWarning,
+			ifNotExist:  checkResultInfo,
+			versionArgs: []string{"--version"},
+			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
+		},
 		&binaryCheck{
 			name:        "gopass-command",
 			binaryname:  c.Gopass.Command,
@@ -359,6 +367,12 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
 			minVersion:  &passholeMinVersion,
 		},
+		&binaryCheck{
+			name:       "rbw-command",
+			binaryname: c.RBW.Command,
+			ifNotSet:   checkResultWarning,
+			ifNotExist: checkResultInfo,
+		},
 		&binaryCheck{
 			name:        "vault-command",
 			binaryname:  c.Vault.Command,
