@@ -47,7 +47,7 @@ var repoGuesses = []struct {
 		sshRepoGuessRepl:  "git@github.com:$1/dotfiles.git",
 	},
 	{
-		rx:                regexp.MustCompile(`\A([-0-9A-Za-z]+)/([-0-9A-Za-z]+)(\.git)?\z`),
+		rx:                regexp.MustCompile(`\A([-0-9A-Za-z]+)/([-\.0-9A-Z_a-z]+?)(\.git)?\z`),
 		httpRepoGuessRepl: "https://github.com/$1/$2.git",
 		sshRepoGuessRepl:  "git@github.com:$1/$2.git",
 	},
@@ -212,13 +212,14 @@ func (c *Config) runInitCmd(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	if err := c.createAndReloadConfigFile(); err != nil {
+	if err := c.createAndReloadConfigFile(cmd); err != nil {
 		return err
 	}
 
 	// Apply.
 	if c.init.apply {
 		if err := c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, noArgs, applyArgsOptions{
+			cmd:          cmd,
 			filter:       c.init.filter,
 			recursive:    false,
 			umask:        c.Umask,
