@@ -140,6 +140,14 @@ func (c *Config) fromIniTemplateFunc(s string) map[string]any {
 	return iniFileToMap(file)
 }
 
+func (c *Config) fromJsoncTemplateFunc(s string) any {
+	var data any
+	if err := chezmoi.FormatJSONC.Unmarshal([]byte(s), &data); err != nil {
+		panic(err)
+	}
+	return data
+}
+
 func (c *Config) fromTomlTemplateFunc(s string) any {
 	var data any
 	if err := chezmoi.FormatTOML.Unmarshal([]byte(s), &data); err != nil {
@@ -414,8 +422,7 @@ func (c *Config) toIniTemplateFunc(data map[string]any) string {
 	return builder.String()
 }
 
-//nolint:revive,stylecheck
-func (c *Config) toPrettyJsonTemplateFunc(args ...any) string {
+func (c *Config) toPrettyJsonTemplateFunc(args ...any) string { //nolint:revive,stylecheck
 	var (
 		indent = "  "
 		value  any
